@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Partition a musical duration into rhythmic phrases
 
-our $VERSION = '0.0602';
+our $VERSION = '0.0700';
 
 use Moo;
 use strictures 2;
@@ -114,6 +114,12 @@ sub _build__pool_group {
 }
 
 
+has remainder => (
+    is      => 'ro',
+    default => sub { return 0 },
+);
+
+
 has verbose => (
     is      => 'ro',
     default => sub { return 0 },
@@ -154,8 +160,13 @@ sub motif {
         my $diff = $self->size - $sum; # How much is left?
 
         # The difference is less than the min_size
-        last
-            if sprintf( $format, $diff ) < sprintf( $format, $self->_min_size );
+        if (sprintf( $format, $diff ) < sprintf( $format, $self->_min_size )) {
+            warn "WARNING: Leftover duration: $diff\n"
+                if $self->verbose;
+            push @$motif, 'd' . sprintf('%.0f', 96 * $diff)
+                if $self->remainder && sprintf($format, 96 * $diff) > 0;
+            last;
+        }
 
         # The note duration is greater than the difference
         next
@@ -204,7 +215,7 @@ Music::Duration::Partition - Partition a musical duration into rhythmic phrases
 
 =head1 VERSION
 
-version 0.0602
+version 0.0700
 
 =head1 SYNOPSIS
 
@@ -324,6 +335,14 @@ Default: Zero for each pool entry
 * Zero and one mean the same thing for grouping.  So if needed, an
 entry should have a value greater than one.
 
+=head2 remainder
+
+  $remainder = $mdp->remainder;
+
+Append any remaining duration ticks to the end of the motif.
+
+Default: C<0>
+
 =head2 verbose
 
   $verbose = $mdp->verbose;
